#!/usr/bin/python
# coding: utf-8

'''pageit: static html generator'''

__author__ = 'The Metaist'
__copyright__ = 'Copyright 2013, Metaist'
__email__ = 'metaist@metaist.com'
__license__ = 'MIT'
__maintainer__ = 'The Metaist'
__status__ = 'Prototype'
__version__ = '0.2.0'
__version_info__ = tuple(__version__.split('.'))

__epilog__ = '''Copyright 2013, Metaist.

Licensed under the terms of the MIT license.
Source code at <https://github.com/metaist/pageit>'''
